@@ -48,23 +48,26 @@ show_result <- function(object) {
 
 #' Fetch records from a previously executed query
 #'
-#' Fetch the next \code{n} elements (rows) from the result set and return them
+#' Fetch the next `n` elements (rows) from the result set and return them
 #' as a data.frame.
 #'
-#' \code{fetch} is provided for compatibility with older DBI clients - for all
-#' new code you are strongly encouraged to use \code{dbFetch}. The default
-#' method for \code{dbFetch} calls \code{fetch} so that it is compatible with
-#' existing code. Implementors are free to provide methods for \code{dbFetch}
-#' only.
+#' `fetch()` is provided for compatibility with older DBI clients - for all
+#' new code you are strongly encouraged to use `dbFetch()`. The default
+#' implementation for `dbFetch()` calls `fetch()` so that it is compatible with
+#' existing code. Modern backends should implement for `dbFetch()` only.
 #'
-#' @param res An object inheriting from \code{\linkS4class{DBIResult}}.
-#' @param n maximum number of records to retrieve per fetch. Use \code{n = -1}
+#' @inherit DBItest::spec_result_fetch return
+#' @inheritSection DBItest::spec_result_fetch Specification
+#' @inheritSection DBItest::spec_result_roundtrip Specification
+#'
+#' @param res An object inheriting from [DBIResult-class], created by
+#'   [dbSendQuery()].
+#' @param n maximum number of records to retrieve per fetch. Use `n = -1`
+#'   or `n = Inf`
 #'   to retrieve all pending records.  Some implementations may recognize other
 #'   special values.
 #' @param ... Other arguments passed on to methods.
-#' @return a data.frame with as many rows as records were fetched and as many
-#'   columns as fields in the result set.
-#' @seealso close the result set with \code{\link{dbClearResult}} as soon as you
+#' @seealso Close the result set with [dbClearResult()] as soon as you
 #'   finish retrieving the records you want.
 #' @family DBIResult generics
 #' @examples
@@ -111,10 +114,11 @@ setGeneric("fetch",
 #' cases (e.g., very large result sets) this can be a critical step to avoid
 #' exhausting resources (memory, file descriptors, etc.)
 #'
-#' @param res An object inheriting from \code{\linkS4class{DBIResult}}.
+#' @inherit DBItest::spec_result_clear_result return
+#' @inheritSection DBItest::spec_result_clear_result Specification
+#'
+#' @param res An object inheriting from [DBIResult-class].
 #' @param ... Other arguments passed on to methods.
-#' @return a logical indicating whether clearing the
-#'   result set was successful or not.
 #' @family DBIResult generics
 #' @export
 #' @examples
@@ -126,8 +130,7 @@ setGeneric("fetch",
 #' dbClearResult(rs)
 #' dbDisconnect(con)
 setGeneric("dbClearResult",
-  def = function(res, ...) standardGeneric("dbClearResult"),
-  valueClass = "logical"
+  def = function(res, ...) standardGeneric("dbClearResult")
 )
 
 #' Information about result types
@@ -138,11 +141,11 @@ setGeneric("dbClearResult",
 #' field (field name, type, etc.)
 #'
 #' @inheritParams dbClearResult
-#' @return A data.frame with one row per output field in \code{res}. Methods
-#'   MUST include \code{name}, \code{field.type} (the SQL type),
-#'   and \code{data.type} (the R data type) columns, and MAY contain other
+#' @return A data.frame with one row per output field in `res`. Methods
+#'   MUST include `name`, `field.type` (the SQL type),
+#'   and `data.type` (the R data type) columns, and MAY contain other
 #'   database specific information like scale and precision or whether the
-#'   field can store \code{NULL}s.
+#'   field can store `NULL`s.
 #' @family DBIResult generics
 #' @export
 #' @examples
@@ -161,10 +164,12 @@ setGeneric("dbColumnInfo",
 
 #' Get the statement associated with a result set
 #'
-#' Returns the statement that was passed to \code{\link{dbSendQuery}}.
+#' Returns the statement that was passed to [dbSendQuery()]
+#' or [dbSendStatement()].
+#'
+#' @inherit DBItest::spec_meta_get_statement return
 #'
 #' @inheritParams dbClearResult
-#' @return a character vector
 #' @family DBIResult generics
 #' @export
 #' @examples
@@ -185,11 +190,13 @@ setGeneric("dbGetStatement",
 #' Completion status
 #'
 #' This method returns if the operation has completed.
-#' A \code{SELECT} query is completed if all rows have been fetched.
-#' A data manipulation statement is completed if it has been executed.
+#' A `SELECT` query is completed if all rows have been fetched.
+#' A data manipulation statement is always completed.
+#'
+#' @inherit DBItest::spec_meta_has_completed return
+#' @inheritSection DBItest::spec_meta_has_completed Specification
 #'
 #' @inheritParams dbClearResult
-#' @return a logical vector of length 1
 #' @family DBIResult generics
 #' @export
 #' @examples
@@ -214,12 +221,12 @@ setGeneric("dbHasCompleted",
 
 #' The number of rows affected
 #'
-#' This function returns the number of rows that were added, deleted, or updated
-#' by a data manipulation statement. For a selection query, this function
-#' returns 0.
+#' This method returns the number of rows that were added, deleted, or updated
+#' by a data manipulation statement.
+#'
+#' @inherit DBItest::spec_meta_get_rows_affected return
 #'
 #' @inheritParams dbClearResult
-#' @return a numeric vector of length 1
 #' @family DBIResult generics
 #' @export
 #' @examples
@@ -240,11 +247,12 @@ setGeneric("dbGetRowsAffected",
 
 #' The number of rows fetched so far
 #'
-#' This value is increased by calls to \code{\link{dbFetch}}. For a data
-#' modifying query, the return value is 0.
+#' Returns the total number of rows actually fetched with calls to [dbFetch()]
+#' for this result set.
+#'
+#' @inherit DBItest::spec_meta_get_row_count return
 #'
 #' @inheritParams dbClearResult
-#' @return a numeric vector of length 1
 #' @family DBIResult generics
 #' @export
 #' @examples
@@ -270,10 +278,10 @@ setGeneric("dbGetRowCount",
 
 #' @name dbGetInfo
 #' @section Implementation notes:
-#' The default implementation for \code{DBIResult objects}
+#' The default implementation for `DBIResult objects`
 #' constructs such a list from the return values of the corresponding methods,
-#' \code{\link{dbGetStatement}}, \code{\link{dbGetRowCount}},
-#' \code{\link{dbGetRowsAffected}}, and \code{\link{dbHasCompleted}}.
+#' [dbGetStatement()], [dbGetRowCount()],
+#' [dbGetRowsAffected()], and [dbHasCompleted()].
 NULL
 #' @rdname hidden_aliases
 setMethod("dbGetInfo", "DBIResult", function(dbObj, ...) {
@@ -286,50 +294,69 @@ setMethod("dbGetInfo", "DBIResult", function(dbObj, ...) {
 })
 
 
-#' Bind values to a parameterised/prepared statement
+#' Bind values to a parameterized/prepared statement
 #'
-#' The \code{\link{dbSendQuery}} function can be called with queries
-#' that contain placeholders for values. This function binds these placeholders
-#' to actual values, and is intended to be called on the result of
-#' \code{\link{dbSendQuery}} before calling \code{\link{dbFetch}}.
+#' For parametrized or prepared statements,
+#' the [dbSendQuery()] and [dbSendStatement()] functions can be called with
+#' statements that contain placeholders for values. The `dbBind()` function
+#' binds these placeholders
+#' to actual values, and is intended to be called on the result set
+#' before calling [dbFetch()] or [dbGetRowsAffected()].
 #'
-#' Parametrised or prepared statements are executed as follows:
+#' \pkg{DBI} supports parametrized (or prepared) queries and statements
+#' via the `dbBind()` generic.
+#' Parametrized queries are different from normal queries
+#' in that they allow an arbitrary number of placeholders,
+#' which are later substituted by actual values.
+#' Parametrized queries (and statements) serve two purposes:
 #'
-#' \enumerate{
-#'   \item Call \code{\link{dbSendQuery}} with a query that contains placeholders,
-#'     store the returned \code{\linkS4class{DBIResult}} object in a variable.
-#'     Currently, the syntax for the placeholders is backend-specific,
-#'     e.g., \code{?}, \code{$}, \code{$name} and \code{:name}.
-#'     Mixing placeholders (in particular, named and unnamed ones) is not
-#'     recommended.
-#'   \item Call \code{\link{dbBind}} on the \code{DBIResult} object with a list
-#'     that specifies actual values for the placeholders.  The list must be
-#'     named or unnamed, depending on the kind of placeholders used.
-#'     Named values are matched to named paramters, unnamed values
-#'     are matched by position.
-#'   \item Call \code{\link{dbFetch}} on the same \code{DBIResult} object.
-#'   \item Repeat 2. and 3. as necessary.
-#'   \item Close the result set via \code{\link{dbClearResult}}.
-#' }
+#' - The same query can be executed more than once with different values.
+#'   The DBMS may cache intermediate information for the query,
+#'   such as the execution plan,
+#'   and execute it faster.
+#' - Separation of query syntax and parameters protects against SQL injection.
+#'
+#' The placeholder format is currently not specified by \pkg{DBI};
+#' in the future, a uniform placeholder syntax may be supported.
+#' Consult the backend documentation for the supported formats.
+#' For automated testing, backend authors specify the placeholder syntax with
+#' the `placeholder_pattern` tweak.
+#' Known examples are:
+#'
+#' - `?` (positional matching in order of appearance) in \pkg{RMySQL} and \pkg{RSQLite}
+#' - `$1` (positional matching by index) in \pkg{RPostgres} and \pkg{RSQLite}
+#' - `:name` and `$name` (named matching) in \pkg{RSQLite}
+#'
+#' @inherit DBItest::spec_meta_bind return
+#' @inheritSection DBItest::spec_meta_bind Specification
 #'
 #' @inheritParams dbClearResult
-#' @param params A list of bindings
+#' @param params A list of bindings, named or unnamed.
 #' @family DBIResult generics
 #' @export
 #' @examples
-#' \dontrun{
 #' con <- dbConnect(RSQLite::SQLite(), ":memory:")
 #'
 #' dbWriteTable(con, "iris", iris)
+#'
+#' # Using the same query for different values
 #' iris_result <- dbSendQuery(con, "SELECT * FROM iris WHERE [Petal.Width] > ?")
 #' dbBind(iris_result, list(2.3))
 #' dbFetch(iris_result)
 #' dbBind(iris_result, list(3))
 #' dbFetch(iris_result)
-#'
 #' dbClearResult(iris_result)
+#'
+#' # Executing the same statement with different values at once
+#' iris_result <- dbSendStatement(con, "DELETE FROM iris WHERE [Species] = $species")
+#' dbBind(iris_result, list(species = c("setosa", "versicolor", "unknown")))
+#' dbGetRowsAffected(iris_result)
+#' dbClearResult(iris_result)
+#'
+#' nrow(dbReadTable(con, "iris"))
+#'
 #' dbDisconnect(con)
-#' }
-setGeneric("dbBind", function(res, params, ...) {
-  standardGeneric("dbBind")
-})
+setGeneric(
+  "dbBind",
+  function(res, params, ...) standardGeneric("dbBind")
+)
